import setuptools

with open ( "README.md" , "r" ) as fh :
    long_description = fh . read ()

setuptools . setup (
    name = "package_fhd" ,
    version = "0.0.1" ,
    author = "infinity" ,
    author_email = "fanghao_w@163.com" ,
    description = "A small example package_fhd" ,
    long_description = long_description ,
    long_description_content_type = "text/markdown" ,
    url = "https://github.com/pypa/sampleproject" ,
    packages = setuptools . find_packages (),
    classifiers = [
        "Programming Language :: Python :: 3" ,
        "License :: OSI Approved :: MIT License" ,
        "Operating System :: OS Independent" ,
    ],
)
